@@ -129,8 +129,9 @@ class ComputeNodeShutdownActorMixin(testutil.ActorTestMixin):
         if not hasattr(self, 'timer'):
             self.make_mocks()
         monitor_actor = dispatch.ComputeNodeMonitorActor.start(
-            self.cloud_node, time.time(), self.shutdowns, self.timer,
-            self.updates, self.arvados_node)
+            self.cloud_node, time.time(), self.shutdowns,
+            testutil.cloud_node_fqdn, self.timer, self.updates,
+            self.arvados_node)
         self.shutdown_actor = self.ACTOR_CLASS.start(
             self.timer, self.cloud_client, monitor_actor, cancellable).proxy()
         self.monitor_actor = monitor_actor.proxy()
@@ -218,8 +219,9 @@ class ComputeNodeMonitorActorTestCase(testutil.ActorTestMixin,
         if start_time is None:
             start_time = time.time()
         self.node_actor = dispatch.ComputeNodeMonitorActor.start(
-            self.cloud_mock, start_time, self.shutdowns, self.timer,
-            self.updates, arv_node).proxy()
+            self.cloud_mock, start_time, self.shutdowns,
+            testutil.cloud_node_fqdn, self.timer, self.updates,
+            arv_node).proxy()
         self.node_actor.subscribe(self.subscriber).get(self.TIMEOUT)
 
     def node_state(self, *states):
@@ -319,6 +321,13 @@ class ComputeNodeMonitorActorTestCase(testutil.ActorTestMixin,
         self.assertIsNone(
             self.node_actor.offer_arvados_pair(arv_node).get(self.TIMEOUT))
 
+    def test_arvados_node_mismatch_first_ping_too_early(self):
+        self.make_actor(4)
+        arv_node = testutil.arvados_node_mock(
+            4, first_ping_at='1971-03-02T14:15:16.1717282Z')
+        self.assertIsNone(
+            self.node_actor.offer_arvados_pair(arv_node).get(self.TIMEOUT))
+
     def test_update_cloud_node(self):
         self.make_actor(1)
         self.make_mocks(2)
@@ -349,3 +358,20 @@ class ComputeNodeMonitorActorTestCase(testutil.ActorTestMixin,
         current_arvados = self.node_actor.arvados_node.get(self.TIMEOUT)
         self.assertEqual(testutil.ip_address_mock(4),
                          current_arvados['ip_address'])
+
+    def test_update_arvados_node_syncs_when_fqdn_mismatch(self):
+        self.make_mocks(5)
+        self.cloud_mock.extra['testname'] = 'cloudfqdn.zzzzz.arvadosapi.com'
+        self.make_actor()
+        arv_node = testutil.arvados_node_mock(5)
+        self.node_actor.update_arvados_node(arv_node).get(self.TIMEOUT)
+        self.assertEqual(1, self.updates.sync_node.call_count)
+
+    def test_update_arvados_node_skips_sync_when_fqdn_match(self):
+        self.make_mocks(6)
+        arv_node = testutil.arvados_node_mock(6)
+        self.cloud_mock.extra['testname'] ='{n[hostname]}.{n[domain]}'.format(
+            n=arv_node)
+        self.make_actor()
+        self.node_actor.update_arvados_node(arv_node).get(self.TIMEOUT)
+        self.assertEqual(0, self.updates.sync_node.call_count)
